summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorLaxman Dewangan <ldewangan@nvidia.com>2012-08-02 19:06:18 +0530
committerSimone Willett <swillett@nvidia.com>2012-08-03 14:02:03 -0700
commit5e7698f9b861a2e24f579eb2b5ab264badd22ad0 (patch)
tree80c8228cd445be3964d8bc2612db6af17e20e4f5 /include
parent9b4f7f573b391a4e6fa5e596e296bef719d67559 (diff)
regulator: tps65090: convert regualtor_init_data as pointer
In regulator platform data for tps65090, convert the regulator init data to a pointer type to have easy support in DT. Change-Id: I00a88e9f12ce5c55880e5c5084357d495bc99b56 Signed-off-by: Laxman Dewangan <ldewangan@nvidia.com> Reviewed-on: http://git-master/r/120837
Diffstat (limited to 'include')
-rw-r--r--include/linux/regulator/tps65090-regulator.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/linux/regulator/tps65090-regulator.h b/include/linux/regulator/tps65090-regulator.h
index 5e27d4a01230..e352a93a7bc7 100644
--- a/include/linux/regulator/tps65090-regulator.h
+++ b/include/linux/regulator/tps65090-regulator.h
@@ -39,12 +39,12 @@ enum {
/*
* struct tps65090_regulator_platform_data
*
* @regulator: The regulator init data.
* @slew_rate_uV_per_us: Slew rate microvolt per microsec.
*/
struct tps65090_regulator_platform_data {
- struct regulator_init_data regulator;
+ struct regulator_init_data *reg_init_data;
};
#endif /* __REGULATOR_TPS65090_H */
@@ -39,12 +39,12 @@ enum {
* struct tps65090_regulator_platform_data
*
- * @regulator: The regulator init data.
+ * @reg_init_data: The regulator init data.
* @slew_rate_uV_per_us: Slew rate microvolt per microsec.
*/